@@ -10,6 +10,7 @@ import tempfile
 
 from testify import *
 from tron import config, mcp, scheduler
+from tron.utils import timeutils
 
 
 def syslog_address_for_platform():
@@ -298,6 +299,190 @@ syslog_address: /does/not/exist"""
         assert_raises(config.ConfigError, test_reconfig.apply, self.my_mcp)
 
 
+class TimeZoneConfigTest(TestCase):
+    """This test is the sibling of scheduler_test.DailySchedulerDSTTest."""
+
+    config = BASE_CONFIG + """
+time_zone: US/Pacific
+jobs:
+    -
+        name: "tz_test_job"
+        node: *node0
+        schedule: "every day at 00:00"
+        actions:
+            -
+                name: "action1_0"
+                command: "test_command1.0"
+    -
+        name: "tz_config_test_job_spring_forward"
+        node: *node0
+        schedule: "every day at 02:30"
+        actions:
+            -
+                name: "action2_0"
+                command: "test_command2.0"
+    -
+        name: "tz_config_test_job_fall_back"
+        node: *node0
+        schedule: "every day at 01:00"
+        actions:
+            -
+                name: "action3_0"
+                command: "test_command3.0"
+    """
+
+    @setup
+    def setup(self):
+        self.tmp_dirs = []
+
+    @teardown
+    def unset_time(self):
+        timeutils.override_current_time(None)
+
+    @teardown
+    def teardown(self):
+        for tmp_dir in self.tmp_dirs:
+            shutil.rmtree(tmp_dir)
+
+    def hours_to_job_at_datetime(self, job_name, *args, **kwargs):
+        """Return the number of hours until the next *two* runs of a job with
+        the given scheduler
+        """
+        # if you need to print a datetime with tz info, use this:
+        #   fmt = '%Y-%m-%d %H:%M:%S %Z%z'
+        #   my_datetime.strftime(fmt)
+
+        test_dir = tempfile.mkdtemp()
+        self.tmp_dirs.append(test_dir)
+        test_config = config.load_config(StringIO.StringIO(self.config))
+        my_mcp = mcp.MasterControlProgram(test_dir, 'config')
+
+        test_config.apply(my_mcp)
+        now = datetime.datetime(*args, **kwargs)
+        timeutils.override_current_time(now)
+        next_run = my_mcp.jobs[job_name].next_runs()[0]
+        t1 = round(next_run.seconds_until_run_time()/60/60, 1)
+        next_run = my_mcp.jobs[job_name].next_runs()[0]
+        t2 = round(next_run.seconds_until_run_time()/60/60, 1)
+        return t1, t2
+
+    def _assert_range(self, x, lower, upper):
+        assert_gt(x, lower)
+        assert_lt(x, upper)
+
+    def test_fall_back(self):
+        """This test checks the behavior of the scheduler at the daylight
+        savings time 'fall back' point, when the system time zone changes
+        from (e.g.) PDT to PST.
+        """
+        # Exact crossover time:
+        # datetime.datetime(2011, 11, 6, 2, 0, 0, tzinfo=pytz.utc)
+        # This test will use times on either side of it.
+
+        # From the PDT vantage point, the run time is 24.2 and 48.2 hours away:
+        s1a, s1b = self.hours_to_job_at_datetime(
+            'tz_test_job', 2011, 11, 6, 0, 50, 0)
+
+        # From the PST vantage point, the run time is 21.8  and 45.8 hours away:
+        s2a, s2b = self.hours_to_job_at_datetime(
+            'tz_test_job', 2011, 11, 6, 2, 10, 0)
+
+        # Make sure the measurements are consistent for each vantage point,
+        # meaning that each run is 24 hours apart no matter where you measure
+        # from, even if the start time appears different for each vantage
+        # point.
+        self._assert_range(s1b - s1a, 23.99, 24.01)
+        self._assert_range(s2b - s2a, 23.99, 24.01)
+
+        # Start times should differ by 2.4 hours.
+        self._assert_range(s1a - s2a, 2.39, 2.41)
+
+    def test_fall_back_2(self):
+        """Identical to test_fall_back, but checks the behavior of jobs
+        scheduled at an ambiguous time.
+        """
+        # Exact crossover time:
+        # datetime.datetime(2011, 11, 6, 2, 0, 0, tzinfo=pytz.utc)
+        # This test will use times on either side of it.
+
+        # From the PDT vantage point, the run time is 1.2 and 25.2 hours away:
+        s1a, s1b = self.hours_to_job_at_datetime(
+            'tz_config_test_job_fall_back', 2011, 11, 6, 0, 50, 0)
+
+        # From the PST vantage point, the run time is 23.8 and 47.8 hours away.
+        # This is an ambiguous time because 1 AM occurs twice. Tron will always
+        # act as if it is in the first block.
+        s2a, s2b = self.hours_to_job_at_datetime(
+            'tz_config_test_job_fall_back', 2011, 11, 6, 1, 10, 0)
+
+        # By this method, the first hour of the repeated 1 AM block is
+        # effectively ignored.
+
+        self._assert_range(s1b - s1a, 23.99, 24.01)
+        self._assert_range(s2b - s2a, 23.99, 24.01)
+
+        # Since the second measurement is taken after the job runs, we check
+        # the 'second' run from the first measurement against the 'first' run
+        # of the first measurement.
+        # Like test_fall_back, start times should differ by 2.4 hours.
+        self._assert_range(s1b - s2a, 1.39, 1.41)
+
+    def test_spring_forward(self):
+        """This test checks the behavior of the scheduler at the daylight
+        savings time 'spring forward' point, when the system time zone changes
+        from (e.g.) PST to PDT.
+        """
+        # Exact crossover time:
+        # datetime.datetime(2011, 3, 13, 2, 0, 0, tzinfo=pytz.utc)
+        # This test will use times on either side of it.
+
+        # From the PST vantage point, the run time is 21.1 hours away:
+        s1a, s1b = self.hours_to_job_at_datetime(
+            'tz_test_job', 2011, 3, 13, 1, 55, 0)
+
+        # From the PDT vantage point, the run time is 20.9 hours away:
+        s2a, s2b = self.hours_to_job_at_datetime(
+            'tz_test_job', 2011, 3, 13, 3, 05, 0)
+
+        self._assert_range(s1b - s1a, 23.99, 24.01)
+        self._assert_range(s2b - s2a, 23.99, 24.01)
+
+        # So we lose an hour here. The 2 AM block does not exist.
+        # If this were not a DST crossover, this difference would be
+        # 1.2, not 0.2.
+        self._assert_range(s1a - s2a, 0.19, 0.21)
+
+    def test_spring_forward_2(self):
+        """Identical to test_spring_forward, but checks the behavior of jobs
+        scheduled at a nonexistent time.
+        """
+        # Exact crossover time:
+        # datetime.datetime(2011, 3, 13, 2, 0, 0, tzinfo=pytz.utc)
+        # This test will use times on either side of it.
+
+        # From the PST vantage point, the run time is 0.6 hours away:
+        s1a, s1b = self.hours_to_job_at_datetime(
+            'tz_config_test_job_spring_forward', 2011, 3, 13, 1, 55, 0)
+
+        # This means the job at the nonexistent time 2:30 will be run at the
+        # "new" 3:30
+        self._assert_range(s1a, 0.59, 0.61)
+
+        # From the PDT vantage point, the next run time is 23.4 hours away,
+        # because the job has already been run.
+        s2a, s2b = self.hours_to_job_at_datetime(
+            'tz_config_test_job_spring_forward', 2011, 3, 13, 3, 05, 0)
+
+        self._assert_range(s1b - s1a, 22.99, 23.01)
+        self._assert_range(s2b - s2a, 23.99, 24.01)
+
+        # Since the second measurement is taken after the job runs, we check
+        # the 'second' run from the first measurement against the 'first' run
+        # of the first measurement.
+        # Like test_spring_forward, the times should differ by 0.2 hours.
+        self._assert_range(s1b - s2a, 0.19, 0.21)
+
+
 class BadJobConfigTest(TestCase):
     @setup
     def build_env(self):
