@@ -2,17 +2,20 @@
 import datetime
 import time
 
+
 # Global time override
 _current_time_override = None
 
+
 def override_current_time(current_time):
     """Interface for overriding the current time
-    
+
     This is a test hook for forcing the app to think it's a specific time.
     """
     global _current_time_override
     _current_time_override = current_time
 
+
 def current_time():
     """Standard interface for generating the current time."""
     if _current_time_override is not None:
@@ -20,13 +23,16 @@ def current_time():
     else:
         return datetime.datetime.now()
 
+
 def current_timestamp():
     return to_timestamp(current_time())
-        
+
+
 def to_timestamp(time_val):
     """Generate a unix timestamp for the given datetime instance"""
     return time.mktime(time_val.timetuple())
 
+
 def macro_timedelta(start_date, years=0, months=0, days=0):
     """Since datetime doesn't provide timedeltas at the year or month level,
     this function generates timedeltas of the appropriate sizes.
@@ -41,6 +47,8 @@ def macro_timedelta(start_date, years=0, months=0, days=0):
         new_month += 12
         years -= 1
 
-    delta += datetime.datetime(start_date.year+years, new_month, start_date.day) - start_date
+    end_date = datetime.datetime(start_date.year + years,
+                                 new_month, start_date.day)
+    delta += end_date - start_date
 
     return delta
